import pytest

from dtgw.vertex_signatures import SIGNATURE_PROVIDERS
import dtgw.dtgw_alternating
from dtgw.config import CONFIG

from helpers import *

@pytest.fixture(params=(True, False))
def linearization(request):
	CONFIG["linearize"] = request.param


@pytest.mark.parametrize("graph_name,signature,distance", [
	("paper_example", SIGNATURE_PROVIDERS["degrees"](), 12),
	("paper_example", SIGNATURE_PROVIDERS["neighbor-degrees"](3), 42),
	("reaction", SIGNATURE_PROVIDERS["degrees"](), 4),
])
def test_dtgw_heuristic(graph_name, signature, distance):
	ltg1, ltg2 = load_tgraphs(graph_name)
	result = dtgw.dtgw(
		ltg1,
		ltg2,
		dtgw.dtgw_alternating.compute_dtgw,
		signature
	)
	assert result == distance


@pytest.mark.usefixtures("linearization")
@pytest.mark.parametrize("graph_name,signature,distance", [
	("paper_example", SIGNATURE_PROVIDERS["degrees"](), 12),
	("paper_example", SIGNATURE_PROVIDERS["neighbor-degrees"](3), 42),
	("reaction", SIGNATURE_PROVIDERS["degrees"](), 4),
])
def test_dtgw_ilp(graph_name, signature, distance):
	dtgw_ilp = pytest.importorskip("dtgw.dtgw_ilp")
	ltg1, ltg2 = load_tgraphs(graph_name)
	result = dtgw.dtgw(
		ltg1,
		ltg2,
		dtgw_ilp.compute_dtgw,
		signature
	)
	assert result == distance